@@ -5,7 +5,7 @@ from dataclasses import dataclass
 from dataclasses import field
 from os import path
 
-from src.ansidocs.classes.layout import Layout
+from ansidocs.classes.layout import Layout
 
 
 @dataclass
