@@ -5,6 +5,7 @@ import logging
 
 from ansidocs.classes.abstract_project_part import AbstractProjectPart
 from ansidocs.classes.abstract_project_part import AbstractDirContent
+from ansidocs.classes.exceptions import DefaultParamMissingDescription
 from ansidocs.classes.layout import Layout
 
 
@@ -30,6 +31,7 @@ class Defaults(AbstractProjectPart):
     def __init__(self, project_root: str, layout: Layout):
         super().__init__(layout=layout, project_root=project_root)
         self.root_dir = path.abspath(path.join(self.project_root, layout.part_paths['defaults']))
+        self.defaults_desc_file = path.join(self.project_root, self.layout.docs, "defaults.yml")
         if not path.exists(self.root_dir):
             raise FileNotFoundError(f"Unable to find defaults project part directory {self.root_dir}")
 
@@ -40,12 +42,11 @@ class Defaults(AbstractProjectPart):
         return defaults
 
     def get_descriptions(self):
-        defaults_desc_file = path.join(self.project_root, self.layout.docs, "defaults.yml")
         try:
-            with open(defaults_desc_file) as f:
+            with open(self.defaults_desc_file) as f:
                 descr = yaml.safe_load(f)
         except FileNotFoundError:
-            logger.critical(f"No defaults description file found at {defaults_desc_file}. "
+            logger.critical(f"No defaults description file found at {self.defaults_desc_file}. "
                             "This file is required when defaults are present")
             raise
         return descr
@@ -53,16 +54,28 @@ class Defaults(AbstractProjectPart):
     def get_content(self):
         content = []
         values = self.get_values()
-        if values:
-            descr = self.get_descriptions()
+        descr = self.get_descriptions()
+        for key in set(list(values.keys()) + list(descr.keys())):
+            try:
+                default_desc = descr[key]
+            except KeyError:
+                raise DefaultParamMissingDescription(name=key, docs_dir=self.defaults_desc_file)
 
-            for k, v in values.items():
-                content += [DefaultParameter(
-                    name=k,
-                    value=v,
-                    required=bool(v == ''),
-                    description=descr.get(k, None)
-                )]
+            try:
+                default_val = values[key]
+                required = False
+            except KeyError:
+                logger.info("Default key {key} has a documented description "
+                            "but is missing a value. Marking as required")
+                default_val = None
+                required = True
+
+            content += [DefaultParameter(
+                name=key,
+                value=default_val,
+                required=required,
+                description=default_desc
+            )]
 
         return DefaultsDirContent(subdirs=[], default_parameters=content)
 
