@@ -2,7 +2,7 @@ import logging
 from os import path
 import yaml
 
-from src.ansidocs.classes.layout import MetaLayout
+from ansidocs.classes.layout import MetaLayout
 
 
 logger = logging.getLogger(__name__)
