@@ -74,7 +74,7 @@ def generate(directory: str, config_dir: str = "ansidocs/config"):
     directory = directory.rstrip('/')
     logger.debug(f"{directory=}")
     logger.debug(f"{config_dir=}")
-    init_config_dir()
+    init_config_dir(config_dir=config_dir)
 
     Config().load_file(config_dir)
     ReadmeWriter().load_templates(config_dir)
